@@ -10,6 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import random
 import uuid
 
 from openstack import exceptions
@@ -34,6 +35,14 @@ class TestBareMetalNode(base.BaseBaremetalTest):
             self.assertEqual(node.id, found.id)
             self.assertEqual(node.name, found.name)
 
+        with_fields = self.conn.baremetal.get_node(
+            'node-name',
+            fields=['uuid', 'driver', 'instance_id'])
+        self.assertEqual(node.id, with_fields.id)
+        self.assertEqual(node.driver, with_fields.driver)
+        self.assertIsNone(with_fields.name)
+        self.assertIsNone(with_fields.provision_state)
+
         nodes = self.conn.baremetal.nodes()
         self.assertIn(node.id, [n.id for n in nodes])
 
@@ -146,6 +155,24 @@ class TestBareMetalNode(base.BaseBaremetalTest):
                                                      wait=True)
         self.assertEqual(node.provision_state, 'available')
 
+    def test_node_create_in_enroll_provide_by_name(self):
+        name = 'node-%d' % random.randint(0, 1000)
+        node = self.create_node(provision_state='enroll', name=name)
+        self.node_id = node.id
+
+        self.assertEqual(node.driver, 'fake-hardware')
+        self.assertEqual(node.provision_state, 'enroll')
+        self.assertIsNone(node.power_state)
+        self.assertFalse(node.is_maintenance)
+
+        node = self.conn.baremetal.set_node_provision_state(name, 'manage',
+                                                            wait=True)
+        self.assertEqual(node.provision_state, 'manageable')
+
+        node = self.conn.baremetal.set_node_provision_state(name, 'provide',
+                                                            wait=True)
+        self.assertEqual(node.provision_state, 'available')
+
     def test_node_power_state(self):
         node = self.create_node()
         self.assertIsNone(node.power_state)
@@ -268,7 +295,8 @@ class TestBareMetalNodeFields(base.BaseBaremetalTest):
 
     def test_node_fields(self):
         self.create_node()
-        result = self.conn.baremetal.nodes(fields=['uuid', 'name'])
+        result = self.conn.baremetal.nodes(
+            fields=['uuid', 'name', 'instance_id'])
         for item in result:
             self.assertIsNotNone(item.id)
             self.assertIsNone(item.driver)
